#!/usr/bin/env node
'use strict';

var _cliColor = require('cli-color');

var _cliColor2 = _interopRequireDefault(_cliColor);

var _execa = require('execa');

var _execa2 = _interopRequireDefault(_execa);

var _minimist2 = require('minimist');

var _minimist3 = _interopRequireDefault(_minimist2);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

var _package = require('../../package.json');

var _package2 = _interopRequireDefault(_package);

var _updateNotifier = require('update-notifier');

var _updateNotifier2 = _interopRequireDefault(_updateNotifier);

var _ansiEscapes = require('ansi-escapes');

var _lodash = require('lodash');

var _figures = require('figures');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var isMac = /^darwin/.test(process.platform);

process.title = 'esbox';

(0, _updateNotifier2.default)({ pkg: _package2.default }).notify();

var red = _cliColor2.default.red;
var black = _cliColor2.default.black;
var bgWhite = _cliColor2.default.xtermSupported ? _cliColor2.default.bgXterm(250) : _cliColor2.default.bgWhite;
var brown = _cliColor2.default.xtermSupported ? _cliColor2.default.xterm(137) : _cliColor2.default.yellow;
var grey = _cliColor2.default.xtermSupported ? _cliColor2.default.xterm(241) : _cliColor2.default.blackBright;

var help = '\n  ' + bgWhite('                       ') + '\n  ' + bgWhite('  ' + (isMac ? '📦' : '') + '  ' + black('ES2016 in a box') + '   ') + '\n  ' + bgWhite('     ' + grey('git.io/esbox') + '      ') + '\n  ' + bgWhite('                       ') + '\n\n  ' + brown('Usage') + '\n    ' + grey('>') + ' esbox ' + grey('FILENAME') + '\n\n  ' + brown('Options') + '\n    --cwd=' + grey('DIRECTORY') + '   run in a different directory\n    --no-watch        only run your script once\n    --no-clear        disable clearing the display before each run\n    --version         show esbox version\n    --poll            poll file system when watching files';

// get input from command line

var _minimist = (0, _minimist3.default)(process.argv.slice(2), {
  default: {
    cwd: null,
    clear: true,
    watch: true,
    help: false,
    version: false,
    poll: false
  },
  string: ['cwd'],
  boolean: ['clear', 'watch', 'help', 'version', 'poll'],
  alias: {
    v: 'version',
    h: 'help'
  }
});

var input = _minimist._;

var flags = _objectWithoutProperties(_minimist, ['_']);

// output version


if (flags.version) {
  console.log(_package2.default.version);
  process.exit(0);
}

// output help
if (flags.help || input.length !== 1) {
  console.log(help);
  process.exit(0);
}

// unpack flags
var clear = flags.clear;
var watch = flags.watch;

var cwd = flags.cwd ? _path2.default.resolve(flags.cwd) : process.cwd();

// determine the real path to the user's script
var userScript = function () {
  var name = _path2.default.resolve(cwd, input[0]);

  // add .js extension if necessary
  if (!_pathExists2.default.sync(name)) name = name + '.js';

  // give up if not found
  if (!_pathExists2.default.sync(name)) {
    console.error(red('Not found: ' + input[0]));
    process.exit(1);
  }
  return name;
}();

// function to clear the display and run the user's script
var run = function () {
  var runner = _path2.default.resolve(__dirname, 'run.js');

  var childProcess = void 0;

  return (0, _lodash.debounce)(function () {
    if (clear) process.stdout.write(_ansiEscapes.clearScreen);

    console.log(brown((isMac ? '📦 ' : 'esbox') + ' ' + _path2.default.relative(process.cwd(), userScript) + '\n'));

    if (childProcess) childProcess.kill();

    childProcess = _execa2.default.spawn('node', [runner, '--file', userScript, '--clear', clear], { cwd: cwd, stdio: 'inherit' });

    childProcess.on('close', function (code) {
      if (code !== null && code !== 143) {
        console.log(brown('\n' + (code === 0 ? _figures.tick : _figures.cross) + ' exited with code ' + code));

        if (!clear) console.log();
      }
    });

    return;
  }, 10, { maxWait: 1000 });
}();

// start up
if (watch) {
  var sane = require('sane');

  var onFileEvent = function onFileEvent(name, root) {
    if (!/\.js$/.test(name)) return;

    delete require.cache[_path2.default.resolve(root, name)];

    run();
  };

  var watcher = sane(cwd, { poll: flags.poll });

  watcher.on('add', onFileEvent);
  watcher.on('change', onFileEvent);
  watcher.on('delete', onFileEvent);

  watcher.on('ready', run);
} else run();
//# sourceMappingURL=cli.js.map