'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = readableStack;

var _builtinModules = require('builtin-modules');

var _builtinModules2 = _interopRequireDefault(_builtinModules);

var _cliColor = require('cli-color');

var _cliColor2 = _interopRequireDefault(_cliColor);

var _isAbsolute = require('is-absolute');

var _isAbsolute2 = _interopRequireDefault(_isAbsolute);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pathExists = require('path-exists');

var _pathExists2 = _interopRequireDefault(_pathExists);

var _stackTrace = require('stack-trace');

var _stackTrace2 = _interopRequireDefault(_stackTrace);

var _subdir = require('subdir');

var _subdir2 = _interopRequireDefault(_subdir);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var grey = _cliColor2.default.xtermSupported ? _cliColor2.default.xterm(241) : _cliColor2.default.blackBright;

function readableStack(error) {
  var options = arguments.length <= 1 || arguments[1] === undefined ? { cwd: process.cwd() } : arguments[1];
  var cwd = options.cwd;


  if (!(error instanceof Error)) return 'Not an error: ' + error;

  return _stackTrace2.default.parse(error).map(function (call) {
    var fileName = call.getFileName();
    var functionName = call.getFunctionName();
    var lineNumber = call.getLineNumber();
    var columnNumber = call.getColumnNumber();

    if ((0, _lodash.isString)(fileName)) {
      var absolute = (0, _isAbsolute2.default)(fileName);
      var resolvedFileName = _path2.default.resolve(cwd, fileName);

      if ((0, _subdir2.default)(cwd, fileName) && !(0, _subdir2.default)(_path2.default.join(cwd, 'node_modules'), resolvedFileName) && (absolute || _builtinModules2.default.indexOf(_path2.default.basename(fileName, '.js')) === -1 && _pathExists2.default.sync(resolvedFileName))) {
        // absolute and within CWD (but not in node_modules folder)
        // - highlight this line
        return (functionName ? grey('  at ') + functionName : ' ') + grey(' in ') + _path2.default.join('./', _path2.default.relative(cwd, fileName)) + (lineNumber ? grey(':' + lineNumber + ':' + columnNumber) : '');
      }

      // anywhere else - dim this line
      return grey((functionName ? '  at ' + functionName : ' ') + ' in ' + _path2.default.relative(cwd, fileName) + (lineNumber ? ':' + lineNumber + ':' + columnNumber : ''));
    }

    // no filename - dim this line
    return grey((functionName ? '  at ' + functionName : ' ') + ' in [unknown]');
  }).join('\n');
}
//# sourceMappingURL=readableStack.js.map